@@ -86,16 +86,14 @@ import os
 from PyQt5 import QtCore, QtGui, QtWidgets
 
 
-
-def spot_main():
+def start():
     from guifolder.gui import MainWindow
-    from main_paras import queueForGui, queueForResult, queueForCom, queueForOffLine
+    from main_paras import queueForGui, queueForResult, queueForCom, queueForOffLine    
     import main_paras
     
-    if sys.platform == 'linux':       
+    if sys.platform == 'linux':
         OnOff      =OnOffThread(4,"OnOff")
         OnOff.start()
-
     TestMonitor=TestChipHandlerThread(3,"TCH",queueForCom, queueForGui, queueForResult)
     TestMonitor.start()
     Comm       =CommunicationThread(2,"Comm",queueForCom, queueForResult)
@@ -120,8 +118,11 @@ def spot_main():
     TestMonitor.join()
     window.close()
     sys.exit(rtn)
+
+def spot_main():
+    if sys.platform == 'linux':
+        preStart()
+    start()
     
 if __name__ == "__main__":
-    if sys.platform == 'linux':           
-        preStart()
     spot_main()
