@@ -179,9 +179,10 @@ MANUAL_OPERATION_RESTART       = 7
 QR_POLLING_TIMEOUT = 10
 NON_QR             ='NON QR'
 
-TEST_MODE_SPEED = 0
-TEST_MODE_NORMAL = 1
-
+TEST_MODE_SPEED = 'Speed'
+TEST_MODE_NORMAL = 'Normal'
+DEFAULT_TEST_MODE = TEST_MODE_NORMAL
+DEFAULT_LANGUAGE = 'English'
 popUp = None
 MAX_PROFILES = 2
 #trans = None
